
CREATE OR REPLACE FUNCTION public.from_days(int4) RETURNS timestamp AS '
    select ''0001-01-02''::timestamp + ($1 || '' days'')::interval as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.from_unixtime(int4) RETURNS timestamp AS '
    select abstime($1)::timestamp as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.if(int4, int4, int4) RETURNS int4 AS '
DECLARE
 expr1 ALIAS FOR $1;
 expr2 ALIAS FOR $2;
 expr3 ALIAS FOR $3;

BEGIN
 IF expr1 is null THEN
  return expr3;
 END IF;
 
 IF expr1=0 THEN
  return expr3;
 END IF;

 RETURN expr2;

END;
'  LANGUAGE 'plpgsql' VOLATILE;


CREATE OR REPLACE FUNCTION public.if(text, text, text) RETURNS text AS '
DECLARE
 expr1 ALIAS FOR $1;
 expr2 ALIAS FOR $2;
 expr3 ALIAS FOR $3;

BEGIN
 IF expr1 is null THEN
  return expr3;
 END IF;
 
 RETURN expr2;

END;
'  LANGUAGE 'plpgsql' VOLATILE;

CREATE OR REPLACE FUNCTION public.to_inet(text) RETURNS inet AS '
DECLARE
 expr1 ALIAS FOR $1;

BEGIN
 IF (expr1 is null OR expr1 = '''') THEN
  return ''0.0.0.0'';
 END IF;
 
 RETURN expr1::inet;

END;
'  LANGUAGE 'plpgsql' VOLATILE;


CREATE OR REPLACE FUNCTION public.if(int8, int8, int8) RETURNS int8 AS '
DECLARE
 expr1 ALIAS FOR $1;
 expr2 ALIAS FOR $2;
 expr3 ALIAS FOR $3;

BEGIN
 IF expr1 is null THEN
  return expr3;
 END IF;
 
 IF expr1=0 THEN
  return expr3;
 END IF;

 RETURN expr2;

END;
'  LANGUAGE 'plpgsql' VOLATILE;
       
CREATE OR REPLACE FUNCTION public.ifnull(text, text) RETURNS text AS '
    select coalesce($1, $2) as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.ifnull(int4, int4) RETURNS int4 AS '
    select coalesce($1, $2) as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.sec_to_time() RETURNS int4 AS '
    select 0::int4 as result
'  LANGUAGE 'sql' VOLATILE;
 
CREATE OR REPLACE FUNCTION public.sec_to_time(int4) RETURNS reltime AS '
    select reltime($1)::reltime as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.to_days(timestamp) RETURNS int4 AS '
    select date_part(''day'', $1 - ''0001-01-01'')::int4 as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.to_days(timestamp with time zone) RETURNS int4 AS '
    select date_part(''day'', $1 - ''0001-01-01'')::int4 as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.to_timestamp(int4) RETURNS timestamp AS '
    select null::timestamp as result
'  LANGUAGE 'sql' VOLATILE;
       
CREATE OR REPLACE FUNCTION public.to_timestamp(date) RETURNS date AS '
    select $1::date as result
'  LANGUAGE 'sql' VOLATILE;
       
CREATE OR REPLACE FUNCTION public.to_timestamp(text) RETURNS date AS '
    select $1::date as result
'  LANGUAGE 'sql' VOLATILE;

CREATE OR REPLACE FUNCTION public.unix_timestamp(timestamp with time zone) RETURNS int4 AS '
DECLARE
 ret_value int4;
 new_year int4;

BEGIN
 IF $1=''1970-01-01 BC'' THEN
  RETURN 0;
 END IF;

 new_year := date_part(''YEAR'', $1);

 IF new_year >= 2020 THEN
  RETURN 0;
 END IF;

 ret_value := extract(epoch from $1)::int4;

 RETURN ret_value;

END; '  LANGUAGE 'plpgsql' VOLATILE;

CREATE OR REPLACE FUNCTION public.unix_timestamp(timestamp without time zone) RETURNS int4 AS '
DECLARE
 ret_value int4;
 new_year int4;

BEGIN
 IF $1=''1970-01-01 00:00:00'' THEN
  RETURN 0;
 END IF;

 new_year := date_part(''YEAR'', $1);

 IF new_year >= 2020 THEN
  RETURN 0;
 END IF;

 ret_value := extract(epoch from $1 at time zone ''GMT'')::int4;

 RETURN ret_value;

END; '  LANGUAGE 'plpgsql' VOLATILE;

CREATE OR REPLACE FUNCTION public.ts_show(timestamp without time zone) RETURNS text AS '
DECLARE
BEGIN
 IF $1=''1970-01-01 00:00:00'' OR $1=''0001-01-01 00:00:00'' THEN
  RETURN '''';
 END IF;
 RETURN $1::text;
END; '  LANGUAGE 'plpgsql' VOLATILE;

CREATE OR REPLACE FUNCTION public.time_show(int8) RETURNS text AS '
DECLARE
    secs int4;
    mins int4;
    hours int4;
BEGIN
 IF $1 is null OR $1=0 THEN
  RETURN '''';
 END IF;
 secs := $1 % 60;
 mins := (($1 - secs) / 60) % 60;
 hours := $1 / 3600;
 RETURN hours::text||'':''||lpad(mins::text,2,''0'')||'':''||lpad(secs::text,2,''0'');
END; '  LANGUAGE 'plpgsql' VOLATILE;
	      
CREATE OR REPLACE FUNCTION public.time_show(numeric) RETURNS text AS '
DECLARE
    secs int4;
    mins int4;
    hours int4;
BEGIN
 IF $1 is null OR $1=0 THEN
  RETURN '''';
 END IF;
 secs := $1 % 60;
 mins := (($1 - secs) / 60) % 60;
 hours := $1 / 3600;
 RETURN hours::text||'':''||lpad(mins::text,2,''0'')||'':''||lpad(secs::text,2,''0'');
END; '  LANGUAGE 'plpgsql' VOLATILE;
	      
