
CREATE TABLE sk_card_data (
  cid serial8 PRIMARY KEY,
  sid int8 NOT NULL default '0',
  pin varchar(20) NOT NULL default '' UNIQUE,
  cost decimal(16,2) NOT NULL default '0',
  status char(1) NOT NULL default 'a',
  used_by int8 NOT NULL default '0',
  used_at timestamp without time zone NOT NULL
);

CREATE TABLE sk_card_error (
  error_time timestamp without time zone NOT NULL default CURRENT_TIMESTAMP PRIMARY KEY,
  error_user int8 NOT NULL default '0',
  error_input text NOT NULL default ''
) WITHOUT OIDS;

CREATE TABLE sk_card_series (
  sid serial8 PRIMARY KEY,
  gid int8 NOT NULL default '0',
  cost numeric(16,2) NOT NULL default '0.00',
  date_add timestamp without time zone NOT NULL default CURRENT_TIMESTAMP,
  date_expire timestamp without time zone NOT NULL default '1970-01-01 00:00',
  url text,
  descr text NOT NULL default '',
  card_type int2 NOT NULL default '0',
  admin int8 NOT NULL default '0',
  cards_col int8 not null default '0'
);

CREATE TABLE sk_group_tracker (
	obj_id int8 default '1' NOT NULL,
	gid int8 default '0' NOT NULL
) WITHOUT OIDS;

CREATE TABLE sk_users (
    username varchar(64) NOT NULL default '',
  password varchar(64) NOT NULL default '*',
  auth_info varchar(64) NOT NULL default '',
  auth_type int2 NOT NULL default '0',
  uid serial8 PRIMARY KEY,
  account_id int8 NOT NULL default '0',
  gid int8 NOT NULL default '1',
  sid int8 NOT NULL default '0',
  deposit numeric(16,2) NOT NULL default '0.00',
  credit numeric(16,2) NOT NULL default '0.00',
  add_date timestamp without time zone NOT NULL default CURRENT_TIMESTAMP,
  tos int2 NULL,
  do_with_tos int2 NULL,
  direction int2 NULL,	
  fixed int2 default '0',	
  fixed_cost numeric(16,2) default '0.0',		
  activation_time int8 NULL,
  total_time_limit int8 default '0',	
  month_time_limit int8 default '0',	
  week_time_limit int8 default '0',	
  day_time_limit int8 default '0',	
  total_traffic_limit int8 default '0',
  month_traffic_limit int8 default '0',
  week_traffic_limit int8 default '0',	
  day_traffic_limit int8 default '0',	
  total_money_limit numeric(16,2) default '0.0',
  month_money_limit numeric(16,2) default '0.0',
  week_money_limit numeric(16,2) default '0.0',	
  day_money_limit numeric(16,2) default '0.0',	
  login_time varchar(254),	
  huntgroup_name varchar(64),		
  simultaneous_use int4 default '1',	
  port_limit int2 default '1',	
  session_timeout int8 default '0',			
  idle_timeout int8 default '0',		
  no_pass int2 default '0',		
  no_acct int2 default '0',		
  allow_callback int2 default '0',	
  other_params TEXT,		
  allowed_servers varchar(254),		
  blocked int2 NOT NULL default '1',
  activated int2 NOT NULL default '0',
  expired timestamp without time zone NOT NULL default '1970-01-01 00:00',	
  total_time int8 NOT NULL default '0',	
  total_traffic int8 NOT NULL default '0',
  total_money numeric(16,2) NOT NULL default '0.00',
  last_connection timestamp without time zone NOT NULL default '1970-01-01 00:00:00',
  framed_ip varchar(16) NOT NULL default '',	
  framed_mask varchar(15) NOT NULL default '',
  framed_route text,
  callback_number varchar(64) NOT NULL default '',
  up int4 default '0',
  down int4 default '0',
  ippool_name varchar(64),
  last_info text,
  res_gid int8 NOT NULL default '0'
);

CREATE TABLE sk_actions (
  username varchar(64) NOT NULL default '',
  uid int8 NOT NULL default '0',
  gid int8 NOT NULL default '0',
  id varchar(64) NOT NULL default '',		
  unique_id varchar(64) NOT NULL default '' UNIQUE,	
  connect_info varchar(254) default NULL,
  time_on int8 NOT NULL default '0',
  start_time timestamp without time zone NOT NULL default CURRENT_TIMESTAMP,
  stop_time timestamp without time zone,
  in_bytes int8 NOT NULL default '0',	
  out_bytes int8 NOT NULL default '0',	
  ip inet,			
  server inet,	
  client_ip inet,	
  port int4 NOT NULL default '0',		
  call_to varchar(128) NOT NULL default '',		
  call_from varchar(128) NOT NULL default '',		
  protocol varchar(12) NULL,
  terminate_cause varchar(64) NOT NULL default '',	
  last_change int4 NOT NULL default '0',	
  hour_in_bytes int8 NOT NULL default '0',
  hour_out_bytes int8 NOT NULL default '0',
  hour_traffic_money numeric(16,2) NOT NULL default '0.00',
  before_billing numeric(16,2) NOT NULL default '0.00',	
  billing_minus numeric(16,2) NOT NULL default '0.00'
) WITHOUT OIDS;
 --------------------------------------------------------

CREATE TABLE sk_actions_01 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=1)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_02 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=2)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_03 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=3)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_04 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=4)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_05 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=5)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_06 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=6)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_07 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=7)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_08 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=8)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_09 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=9)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_10 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=10)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_11 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=11)) INHERITS (sk_actions) WITHOUT OIDS;
CREATE TABLE sk_actions_12 ( CONSTRAINT "$1" CHECK (extract(month from start_time)=12)) INHERITS (sk_actions) WITHOUT OIDS;

CREATE OR REPLACE RULE act_ins_01 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 1 DO INSTEAD
INSERT INTO sk_actions_01 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_02 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 2 DO INSTEAD
INSERT INTO sk_actions_02 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_03 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 3 DO INSTEAD
INSERT INTO sk_actions_03 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_04 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 4 DO INSTEAD
INSERT INTO sk_actions_04 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_05 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 5 DO INSTEAD
INSERT INTO sk_actions_05 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_06 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 6 DO INSTEAD
INSERT INTO sk_actions_06 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_07 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 7 DO INSTEAD
INSERT INTO sk_actions_07 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_08 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 8 DO INSTEAD
INSERT INTO sk_actions_08 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_09 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 9 DO INSTEAD
INSERT INTO sk_actions_09 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_10 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 10 DO INSTEAD
INSERT INTO sk_actions_10 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_11 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 11 DO INSTEAD
INSERT INTO sk_actions_11 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);

CREATE OR REPLACE RULE act_ins_12 AS ON INSERT TO sk_actions WHERE extract(month from new.start_time) = 12 DO INSTEAD
INSERT INTO sk_actions_12 (username,uid,gid,id,unique_id,connect_info,time_on,start_time,stop_time,
in_bytes,out_bytes,ip,server,client_ip,port,call_to,call_from,protocol,terminate_cause,last_change,
before_billing,billing_minus) VALUES(NEW.username,NEW.uid,NEW.gid,NEW.id,NEW.unique_id,NEW.connect_info,
NEW.time_on,NEW.start_time,NEW.stop_time,NEW.in_bytes,NEW.out_bytes,NEW.ip,NEW.server,NEW.client_ip,
NEW.port,NEW.call_to,NEW.call_from,NEW.protocol,NEW.terminate_cause,NEW.last_change,NEW.before_billing,NEW.billing_minus);


CREATE TABLE sk_packets (
  gid serial8 PRIMARY KEY,
  packet varchar(128) NOT NULL default '',
  deposit numeric(16,2) NOT NULL default '0.00',
  credit numeric(16,2) NOT NULL default '0.00',
  tos int2 NOT NULL default '0',
  do_with_tos int2 NOT NULL default '1',
  direction int2 NOT NULL default '0',	
  fixed int2 NOT NULL default '0',	
  fixed_cost numeric(16,2) NOT NULL default '0.00',
  activated int2 NOT NULL default '0',	
  activation_time int8 NOT NULL default '2678400',	
  blocked int2 NOT NULL default '0',	
  total_time_limit int8 NOT NULL default '0',
  month_time_limit int8 NOT NULL default '0',
  week_time_limit int8 NOT NULL default '0',
  day_time_limit int8 NOT NULL default '0',
  total_traffic_limit int8 NOT NULL default '0',
  month_traffic_limit int8 NOT NULL default '0',
  week_traffic_limit int8 NOT NULL default '0',
  day_traffic_limit int8 NOT NULL default '0',
  total_money_limit numeric(16,2) NOT NULL default '0.00',	
  month_money_limit numeric(16,2) NOT NULL default '0.00',	
  week_money_limit numeric(16,2) NOT NULL default '0.00',	
  day_money_limit numeric(16,2) NOT NULL default '0.00',	
  login_time varchar(254) NOT NULL default '',		
  huntgroup_name varchar(64) NOT NULL default '',		
  simultaneous_use int4 NOT NULL default '1',	
  port_limit int2 NOT NULL default '0',	
  session_timeout int8 NOT NULL default '0',	
  idle_timeout int8 NOT NULL default '0',	
  framed_ip varchar(16) NOT NULL default '',			
  framed_mask varchar(15) NOT NULL default '',		
  no_pass int2 NOT NULL default '0',		
  no_acct int2 NOT NULL default '0',		
  allow_callback int2 NOT NULL default '0',	
  other_params TEXT,
  framed_route text,
  allowed_servers varchar(254),				
  up int4 not null default '0',				
  down int4 not null default '0',
  cos int4 not null default '0',
  ippool_name varchar(64),
  users_col int8 not null default '0',
  service_set_id int8 not null default '1'
);

CREATE TABLE sk_prices (
  gid int8 NOT NULL default '1',
  week_day int2 NOT NULL default '0',
  h0 numeric(10,6) NOT NULL default '0.000000',
  input0 numeric(10,6) NOT NULL default '0.000000',
  output0 numeric(10,6) NOT NULL default '0.000000',
  h1 numeric(10,6) NOT NULL default '0.000000',
  input1 numeric(10,6) NOT NULL default '0.000000',
  output1 numeric(10,6) NOT NULL default '0.000000',
  h2 numeric(10,6) NOT NULL default '0.000000',
  input2 numeric(10,6) NOT NULL default '0.000000',
  output2 numeric(10,6) NOT NULL default '0.000000',
  h3 numeric(10,6) NOT NULL default '0.000000',
  input3 numeric(10,6) NOT NULL default '0.000000',
  output3 numeric(10,6) NOT NULL default '0.000000',
  h4 numeric(10,6) NOT NULL default '0.000000',
  input4 numeric(10,6) NOT NULL default '0.000000',
  output4 numeric(10,6) NOT NULL default '0.000000',
  h5 numeric(10,6) NOT NULL default '0.000000',
  input5 numeric(10,6) NOT NULL default '0.000000',
  output5 numeric(10,6) NOT NULL default '0.000000',
  h6 numeric(10,6) NOT NULL default '0.000000',
  input6 numeric(10,6) NOT NULL default '0.000000',
  output6 numeric(10,6) NOT NULL default '0.000000',
  h7 numeric(10,6) NOT NULL default '0.000000',
  input7 numeric(10,6) NOT NULL default '0.000000',
  output7 numeric(10,6) NOT NULL default '0.000000',
  h8 numeric(10,6) NOT NULL default '0.000000',
  input8 numeric(10,6) NOT NULL default '0.000000',
  output8 numeric(10,6) NOT NULL default '0.000000',
  h9 numeric(10,6) NOT NULL default '0.000000',
  input9 numeric(10,6) NOT NULL default '0.000000',
  output9 numeric(10,6) NOT NULL default '0.000000',
  h10 numeric(10,6) NOT NULL default '0.000000',
  input10 numeric(10,6) NOT NULL default '0.000000',
  output10 numeric(10,6) NOT NULL default '0.000000',
  h11 numeric(10,6) NOT NULL default '0.000000',
  input11 numeric(10,6) NOT NULL default '0.000000',
  output11 numeric(10,6) NOT NULL default '0.000000',
  h12 numeric(10,6) NOT NULL default '0.000000',
  input12 numeric(10,6) NOT NULL default '0.000000',
  output12 numeric(10,6) NOT NULL default '0.000000',
  h13 numeric(10,6) NOT NULL default '0.000000',
  input13 numeric(10,6) NOT NULL default '0.000000',
  output13 numeric(10,6) NOT NULL default '0.000000',
  h14 numeric(10,6) NOT NULL default '0.000000',
  input14 numeric(10,6) NOT NULL default '0.000000',
  output14 numeric(10,6) NOT NULL default '0.000000',
  h15 numeric(10,6) NOT NULL default '0.000000',
  input15 numeric(10,6) NOT NULL default '0.000000',
  output15 numeric(10,6) NOT NULL default '0.000000',
  h16 numeric(10,6) NOT NULL default '0.000000',
  input16 numeric(10,6) NOT NULL default '0.000000',
  output16 numeric(10,6) NOT NULL default '0.000000',
  h17 numeric(10,6) NOT NULL default '0.000000',
  input17 numeric(10,6) NOT NULL default '0.000000',
  output17 numeric(10,6) NOT NULL default '0.000000',
  h18 numeric(10,6) NOT NULL default '0.000000',
  input18 numeric(10,6) NOT NULL default '0.000000',
  output18 numeric(10,6) NOT NULL default '0.000000',
  h19 numeric(10,6) NOT NULL default '0.000000',
  input19 numeric(10,6) NOT NULL default '0.000000',
  output19 numeric(10,6) NOT NULL default '0.000000',
  h20 numeric(10,6) NOT NULL default '0.000000',
  input20 numeric(10,6) NOT NULL default '0.000000',
  output20 numeric(10,6) NOT NULL default '0.000000',
  h21 numeric(10,6) NOT NULL default '0.000000',
  input21 numeric(10,6) NOT NULL default '0.000000',
  output21 numeric(10,6) NOT NULL default '0.000000',
  h22 numeric(10,6) NOT NULL default '0.000000',
  input22 numeric(10,6) NOT NULL default '0.000000',
  output22 numeric(10,6) NOT NULL default '0.000000',
  h23 numeric(10,6) NOT NULL default '0.000000',
  input23 numeric(10,6) NOT NULL default '0.000000',
  output23 numeric(10,6) NOT NULL default '0.000000',
  servers varchar(254) NULL,
  price_type int2 NOT NULL default '0',
  uid int8 NOT NULL default '0'
) WITHOUT OIDS;

CREATE TABLE sk_radlog (
  insertion_time timestamp without time zone default CURRENT_TIMESTAMP,
  rad_time varchar(64),
  rad_msg text 
);

CREATE TABLE sk_radlog_01 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=1)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_02 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=2)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_03 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=3)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_04 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=4)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_05 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=5)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_06 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=6)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_07 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=7)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_08 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=8)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_09 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=9)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_10 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=10)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_11 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=11)) INHERITS (sk_radlog) WITHOUT OIDS;
CREATE TABLE sk_radlog_12 ( CONSTRAINT "$1" CHECK (extract(month from insertion_time)=12)) INHERITS (sk_radlog) WITHOUT OIDS;

CREATE OR REPLACE RULE radlog_ins_01 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 1 DO INSTEAD
INSERT INTO sk_radlog_01 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_02 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 2 DO INSTEAD
INSERT INTO sk_radlog_02 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_03 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 3 DO INSTEAD
INSERT INTO sk_radlog_03 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_04 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 4 DO INSTEAD
INSERT INTO sk_radlog_04 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_05 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 5 DO INSTEAD
INSERT INTO sk_radlog_05 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_06 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 6 DO INSTEAD
INSERT INTO sk_radlog_06 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_07 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 7 DO INSTEAD
INSERT INTO sk_radlog_07 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_08 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 8 DO INSTEAD
INSERT INTO sk_radlog_08 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_09 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 9 DO INSTEAD
INSERT INTO sk_radlog_09 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_10 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 10 DO INSTEAD
INSERT INTO sk_radlog_10 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_11 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 11 DO INSTEAD
INSERT INTO sk_radlog_11 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE RULE radlog_ins_12 AS ON INSERT TO sk_radlog WHERE extract(month from new.insertion_time) = 12 DO INSTEAD
INSERT INTO sk_radlog_12 (insertion_time,rad_time,rad_msg) VALUES(NEW.insertion_time,NEW.rad_time,NEW.rad_msg);

CREATE OR REPLACE VIEW sk_online AS SELECT * FROM sk_actions WHERE Terminate_Cause = 'Online' ORDER BY uid;

create or replace view sk_expired_1h as select sk_users.uid as uid, sk_users.username as username, sk_packets.packet as packet, 
sk_users.deposit as deposit, sk_users.credit as credit, sk_users.expired as expired, 
sk_users.last_connection as last_connection, sk_users.total_time as total_time, 
sk_users.total_traffic as total_traffic, sk_users.total_money as total_money, 
sk_users.blocked as blocked, sk_users.gid as gid, sk_packets.service_set_id as service_set_id 
from sk_users, sk_packets where sk_users.gid=sk_packets.gid and (sk_users.total_time_limit=3600 or sk_packets.total_time_limit=3600);

create or replace view sk_expired_24h as select sk_users.uid as uid, sk_users.username as username, sk_packets.packet as packet, 
sk_users.deposit as deposit, sk_users.credit as credit, sk_users.expired as expired, 
sk_users.last_connection as last_connection, sk_users.total_time as total_time, 
sk_users.total_traffic as total_traffic, sk_users.total_money as total_money, 
sk_users.blocked as blocked, sk_users.gid as gid, sk_packets.service_set_id as service_set_id 
from sk_users, sk_packets where sk_users.gid=sk_packets.gid and (sk_users.total_time_limit=86400 or sk_packets.total_time_limit=86400);

CREATE OR REPLACE VIEW sk_stat_month_uid AS SELECT uid, user, sum(time_on) as time_on, sum(in_bytes) as in_bytes, sum(out_bytes) as out_bytes, sum(billing_minus) as billing_minus FROM sk_actions WHERE extract(month from start_time) = extract(month from CURRENT_TIMESTAMP) AND extract(year from start_time) = extract(year from CURRENT_TIMESTAMP) GROUP BY sk_actions.uid;
CREATE OR REPLACE VIEW sk_stat_week_uid AS SELECT uid, user, sum(time_on) as time_on, sum(in_bytes) as in_bytes, sum(out_bytes) as out_bytes, sum(billing_minus) as billing_minus FROM sk_actions WHERE extract(year from start_time) = extract(year from CURRENT_TIMESTAMP) AND extract(month from start_time) = extract(month from CURRENT_TIMESTAMP) AND extract(week from start_time) = extract(week from CURRENT_TIMESTAMP) GROUP BY sk_actions.uid;
CREATE OR REPLACE VIEW sk_stat_day_uid AS SELECT uid, user, sum(time_on) as time_on, sum(in_bytes) as in_bytes, sum(out_bytes) as out_bytes, sum(billing_minus) as billing_minus FROM sk_actions WHERE extract(day from start_time) = extract(day from CURRENT_TIMESTAMP) GROUP BY sk_actions.uid;

CREATE OR REPLACE VIEW sk_enabled_packets AS SELECT sk_packets.gid AS gid FROM sk_packets, sk_service_set, sk_providers 
WHERE sk_packets.service_set_id = sk_service_set.service_set_id AND sk_service_set.provider_id = sk_providers.provider_id AND sk_providers.role='P' AND sk_providers.active='Y'
EXCEPT SELECT sk_packets.gid AS gid FROM sk_packets, sk_group_tracker, sk_providers
WHERE sk_packets.gid=sk_group_tracker.gid AND sk_group_tracker.obj_id=sk_providers.obj_id AND sk_providers.role='R' AND sk_providers.active='N';

CREATE OR REPLACE VIEW sk_enabled_users AS
SELECT sk_users.username as username, sk_users.gid as gid, sk_users.auth_type as auth_type, sk_users.password as password, sk_users.auth_info as auth_info
FROM sk_users, sk_enabled_packets WHERE sk_users.gid=sk_enabled_packets.gid;

CREATE OR REPLACE VIEW sk_authorize_users AS
SELECT sk_users.username, sk_users.password, sk_users.auth_type, sk_users.uid, sk_users.gid, sk_users.deposit, sk_users.credit, 
extract(epoch from sk_users.add_date at time zone 'GMT')::int4 as add_date, sk_users.blocked, sk_users.activated, 
extract(epoch from sk_users.expired at time zone 'GMT')::int4 as expired, sk_users.total_time, sk_users.total_traffic, sk_users.total_money, 
extract(epoch from sk_users.last_connection at time zone 'GMT')::int4 as last_connection, sk_users.framed_ip, sk_users.framed_mask, sk_users.callback_number, 
sk_users.tos, sk_users.do_with_tos, sk_users.direction, sk_users.fixed, sk_users.fixed_cost, sk_users.activation_time, 
sk_users.total_time_limit, sk_users.month_time_limit, sk_users.week_time_limit, sk_users.day_time_limit, sk_users.total_traffic_limit, 
sk_users.month_traffic_limit, sk_users.week_traffic_limit, sk_users.day_traffic_limit, sk_users.total_money_limit, 
sk_users.month_money_limit, sk_users.week_money_limit, sk_users.day_money_limit, sk_users.login_time, sk_users.huntgroup_name, 
sk_users.simultaneous_use, sk_users.port_limit, sk_users.session_timeout, sk_users.idle_timeout, sk_users.ippool_name, sk_users.no_pass, 
sk_users.no_acct, sk_users.allow_callback, sk_users.other_params, sk_users.allowed_servers, sk_users.auth_info, sk_users.up, sk_users.down, 
sk_users.framed_route, sk_packets.service_set_id FROM sk_users, sk_packets WHERE sk_packets.gid=sk_users.gid;
